require File.expand_path('../test_helper', __FILE__)

class DataTest < Formatter::TestCase
  def test_all_events_presents
    assert_equal 14, fixture_files.size

    fixture_files.each do |file|
      content = Yajl.load(File.read(file))
      receiver = GitHub::Payload.for(content)
      assert receiver.payload['event']
    end
  end

  def test_push_summary
    content  = load_fixture("push_event")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] atmos pushed 1 new commit to master", receiver.summary_message
    assert_equal "https://github.com/atmos/test/commit/12c8e95fe799c4545d932ee5245ef2a53735d1ae",
      receiver.summary_url
  end

  def test_branch_created_summary
    content  = load_fixture("push_created")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] fakeatmos created logo from master", receiver.summary_message
    assert_equal "https://github.com/atmos/test/commits/logo", receiver.summary_url
  end

  def test_branch_deleted_summary
    content  = load_fixture("push_deleted")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] fakeatmos deleted logo at dcbb4e7", receiver.summary_message
    assert_equal "https://github.com/atmos/test/commit/dcbb4e7", receiver.summary_url
  end

  def test_pull_request_opened_summary
    content  = load_fixture("pull_request_opened")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] fakeatmos opened pull request #2: Update README.md (master...logo)",
                 receiver.summary_message
    assert_equal "https://github.com/atmos/test/pull/2", receiver.summary_url
  end

  def test_pull_request_closed_summary
    content  = load_fixture("pull_request_closed")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] atmos closed pull request #2: Update README.md (master...logo)",
                 receiver.summary_message
    assert_equal "https://github.com/atmos/test/pull/2", receiver.summary_url
  end

  def test_toggling_repo_public
    content  = load_fixture("public")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] atmos just made the repo public.", receiver.summary_message
    assert_equal "https://github.com/atmos/test", receiver.summary_url
  end

  def test_issue_opening
    content  = load_fixture("issues_opened")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] fakeatmos opened issue #1: Images would be cool.", 
      receiver.summary_message
    assert_equal "https://github.com/atmos/test/issues/1", receiver.summary_url
  end

  def test_issue_closing
    content  = load_fixture("issues_closed")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] atmos closed issue #1: Images would be cool.", 
      receiver.summary_message
    assert_equal "https://github.com/atmos/test/issues/1", receiver.summary_url
  end

  def test_issue_comment_created
    content  = load_fixture("issue_comment_created")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] atmos just commented.", receiver.summary_message
    assert_equal "https://api.github.com/repos/atmos/test/issues/comments/19092978",
      receiver.summary_url
  end

  def test_created_branch
    content  = load_fixture("create_branch")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] fakeatmos just created logo.", receiver.summary_message
    assert_equal "https://github.com/atmos/test/commits/logo", receiver.summary_url
  end

  def test_deleted_branch
    content  = load_fixture("delete_branch")
    receiver = GitHub::Payload.for(content)

    assert_equal "[test] fakeatmos just deleted logo.", receiver.summary_message
    assert_equal "https://github.com/atmos/test", receiver.summary_url
  end
end
